@@ -14,6 +14,8 @@ from ovito.vis import SurfaceMeshVis
 from ovito.pipeline import ModifierInterface
 from ovito.modifiers import ColorByTypeModifier
 from traits.api import Bool, Code, Instance
+from ovito.traits import *
+from ovito.traits import *
 import numpy.typing as npt
 from typing import Any, List
 from collections import namedtuple
@@ -126,7 +128,7 @@ class RegionStyle:
         verts = verts + offset
         return verts
 
-    def generate_mesh(self, mesh: SurfaceMesh, color: tuple):
+    def generate_mesh(self, mesh: SurfaceMesh):
         # Add element type to 'Region ID' property of SurfaceMesh
         mesh.regions_.count += 1
         mesh.regions_['Region ID_'][-1] = mesh.regions.count
@@ -135,7 +137,6 @@ class RegionStyle:
         if existing_region_id:
             print(f"Warning: Region ID '{self.region_id}' already exists in the output mesh (numeric id {existing_region_id.id}). Consider renaming it.")
         region_type = mesh.regions_['Region ID_'].add_type_id(mesh.regions.count, mesh.regions, self.region_id)
-        region_type.color = color
         # Generate vertices and faces
         verts, faces = self.generate_verts_and_faces(mesh.domain)
         # Apply 'move'/'rotate' options to verts
@@ -429,7 +430,8 @@ class Cylinder(RegionStyle):
         bottom_plane[:,i] += self.lo
         top_plane[:,i] += self.hi
 
-        verts = np.concatenate((bottom_plane, top_plane))
+        verts = np.concatenate((top_plane, bottom_plane))
+        verts = np.concatenate((top_plane, bottom_plane))
         if self.dim == "x":
             verts[:,1] += self.c1
             verts[:,2] += self.c2
@@ -606,7 +608,8 @@ class Sphere(RegionStyle):
                         edge0 = vertices[first]
                         edge1 = vertices[second]
                         point = np.asarray(edge1) + np.asarray(edge0)
-                        point/=np.linalg.norm(point)
+                        point /= np.linalg.norm(point)
+                        point /= np.linalg.norm(point)
                         vertices.append(point)
                         new_vertex_cache[key] = len(vertices) - 1
                     mid[edge] = new_vertex_cache[key]
@@ -763,22 +766,52 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
 
     """
 
-    commands = Code(value = 'region 1 sphere 0 0 0 20' , label='Region commands')
+    commands = Code(value='region 1 sphere -20 0 0 15\nregion 2 cylinder z 10 0 5 INF INF', label='', ovito_group='Region commands')
+    commands = Code(value='region 1 sphere -20 0 0 15\nregion 2 cylinder z 10 0 5 INF INF', label='', ovito_group='Region commands')
     """
-    The `LAMMPS region <https://docs.lammps.org/region.html>`__ command(s) to be interpreted by the modifier.
+    The `LAMMPS region command(s) <https://docs.lammps.org/region.html>`__ to be interpreted by the modifier.
+    The `LAMMPS region command(s) <https://docs.lammps.org/region.html>`__ to be interpreted by the modifier.
     If multiple commands are specified, they must be separated by new-line characters.
 
-    :Default: ``'region 1 sphere 0 0 0 20'``
+    :Default: ``'region 1 sphere -20 0 0 15'``
+    :Default: ``'region 1 sphere -20 0 0 15'``
     """
 
-    select_atoms = Bool(default_value=False, label='Select atoms')
+    color_by_type = Bool(default_value=False, label='Color by region', ovito_group='Options')
+    color_by_type = Bool(default_value=False, label='Color by region', ovito_group='Options')
     """
-    Turns on the selection of all atoms that are located within one of the generated regions.
+    Controls whether the modifier should color the parts of the surface mesh by region.
+    The effect of this option is the same as if you would additionally insert the :py:class:`~ovito.modifiers.ColorByTypeModifier` into the pipeline.
+
+    If turned off, the mesh will have a uniform color by default and you can make use of the color mapping options of the :py:attr:`vis` element
+    to configure a different coloring scheme if necessary.
+
+    If turned on, the modifier will generate the :ref:`mesh region property <surface-mesh-region-properties-list>` ``Color``,
+    and the mesh will be rendered using the values stored in this property. The modifier assigns a prescribed set of colors to the regions
+    in a cyclic manner.
+    Controls whether the modifier should color the parts of the surface mesh by region.
+    The effect of this option is the same as if you would additionally insert the :py:class:`~ovito.modifiers.ColorByTypeModifier` into the pipeline.
+
+    If turned off, the mesh will have a uniform color by default and you can make use of the color mapping options of the :py:attr:`vis` element
+    to configure a different coloring scheme if necessary.
+
+    If turned on, the modifier will generate the :ref:`mesh region property <surface-mesh-region-properties-list>` ``Color``,
+    and the mesh will be rendered using the values stored in this property. The modifier assigns a prescribed set of colors to the regions
+    in a cyclic manner.
+
+    :Default: ``False``
+
+    .. versionadded:: 3.10.0
+    """
+
+    select_atoms = Bool(default_value=False, label='Select interior particles', ovito_group='Options')
+    """
+    Turns on the selection of all particles that are located within any of the generated regions.
 
     :Default: ``False``
     """
 
-    vis = Instance(SurfaceMeshVis, kw={'title': 'LAMMPS Regions', 'smooth_shading': False, 'clip_at_domain_boundaries': True})
+    vis = OvitoObjectTrait(SurfaceMeshVis, title='LAMMPS Regions', smooth_shading=False, clip_at_domain_boundaries=True)
     """
     The :py:class:`~ovito.vis.SurfaceMeshVis` element that is responsible for rendering the surface mesh generated by the modifier.
     It controls the visual appearance of the region surfaces.
@@ -795,29 +828,34 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
             # Note: For the time being, we have to clone the entire DataCollection, because the Python API has no way of copying just the SimulationCell object.
             copy = data.clone()
             copy.cell_.pbc = (False, False, False)
+            copy.cell_.vis = None
+            copy.cell_.vis = None
 
             surface_mesh = data.surfaces.create('lammps-regions', domain=copy.cell, title='LAMMPS Regions', vis=self.vis)
         else:
-             surface_mesh = data.surfaces['lammps-regions']
+            surface_mesh = data.surfaces['lammps-regions']
+            surface_mesh = data.surfaces['lammps-regions']
         if 'Region ID' not in surface_mesh.regions:
             surface_mesh.regions_.create_property('Region ID', components=1, dtype=int)
         if "Region" not in surface_mesh.faces:
             surface_mesh.faces_.create_property('Region')
 
-        region_color_map = iter([(0.828, 0.864, 0.514), (0.575, 0.239, 0.359), (0.112, 0.277, 0.496), (0.228, 0.104, 0.517), (0.058, 0.512, 0.376), (0.131, 0.769, 0.753)])
-
         if self.select_atoms:
             sel = data.particles_.create_property('Selection', data=0)
 
         for command in self.cleanup_input(self.commands):
             region = self.parse_region_command(str(command))
-            region.generate_mesh(surface_mesh, color = next(region_color_map))
+            region.generate_mesh(surface_mesh)
+            region.generate_mesh(surface_mesh)
             if self.select_atoms:
                 np.logical_or(sel, region.is_inside(data.particles.positions), out=sel[...])
         surface_mesh.connect_opposite_halfedges()
 
         # Color mesh faces by region type
-        data.apply(ColorByTypeModifier(property = 'Region ID', operate_on = 'regions:lammps-regions/regions'))
+        if self.color_by_type:
+            data.apply(ColorByTypeModifier(property = 'Region ID', operate_on = 'regions:lammps-regions/regions'))
+        if self.color_by_type:
+            data.apply(ColorByTypeModifier(property = 'Region ID', operate_on = 'regions:lammps-regions/regions'))
 
     def parse_region_command(self, command: str):
         tokens = command.split()
@@ -836,6 +874,8 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
         return supported_region_styles[style_name](tokens)
 
     def cleanup_input(self, code: str):
+        code = code.strip()
+        code = code.strip()
         lines = []
         input = iter(code.split("\n"))
         line = next(input).strip()
